@@ -1,9 +1,8 @@
 package Net::Google::Analytics::AccountFeedEntry;
-BEGIN {
-  $Net::Google::Analytics::AccountFeedEntry::VERSION = '0.11000';
-}
 use strict;
 
+# ABSTRACT: Google Analytics API account feed entry
+
 use base qw(Class::Accessor Net::Google::Analytics::XML);
 
 my @property_map = (
@@ -17,7 +16,7 @@ my @property_map = (
 
 __PACKAGE__->mk_accessors(qw(
     account_id account_name profile_id web_property_id currency timezone
-    table_id
+    table_id title
 ));
 
 sub _parse {
@@ -36,26 +35,32 @@ sub _parse {
         );
     }
 
-    $self->{table_id} = $node->findvalue('dxp:tableId');
+    $self->{table_id} = $xpc->findvalue('dxp:tableId', $node);
+    $self->{title}    = $xpc->findvalue('atom:title',  $node);
 
     return bless($self, $package);
 }
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
-Net::Google::Analytics::AccountFeedEntry - Google Analytics API account feed
-entry
+Net::Google::Analytics::AccountFeedEntry - Google Analytics API account feed entry
+
+=head1 VERSION
+
+version 0.11001
 
 =head1 DESCRIPTION
 
 This package implements account feed entries of the Google Analytics Data
 Export API.
 
-=head1 ACCESSORS
+=head1 ATTRIBUTES
 
 =head2 account_id
 
@@ -71,17 +76,22 @@ Export API.
 
 =head2 table_id
 
+=head2 title
+
 =head1 AUTHOR
 
 Nick Wellnhofer <wellnhofer@aevum.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) Nick Wellnhofer, 2010
+This software is copyright (c) 2010 by Nick Wellnhofer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.0 or,
-at your option, any later version of Perl 5 you may have available.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
+
