@@ -1,9 +1,8 @@
 package Net::Google::Analytics::AccountFeedResponse;
-BEGIN {
-  $Net::Google::Analytics::AccountFeedResponse::VERSION = '0.11000';
-}
 use strict;
 
+# ABSTRACT: Google Analytics API account feed response
+
 use base qw(Net::Google::Analytics::FeedResponse);
 
 use Net::Google::Analytics::AccountFeedEntry;
@@ -19,12 +18,17 @@ sub _parse_entry {
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
-Net::Google::Analytics::AccountFeedResponse - Google Analytics API account
-feed response
+Net::Google::Analytics::AccountFeedResponse - Google Analytics API account feed response
+
+=head1 VERSION
+
+version 0.11001
 
 =head1 DESCRIPTION
 
@@ -43,11 +47,14 @@ Nick Wellnhofer <wellnhofer@aevum.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) Nick Wellnhofer, 2010
+This software is copyright (c) 2010 by Nick Wellnhofer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.0 or,
-at your option, any later version of Perl 5 you may have available.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
+
