@@ -1,9 +1,8 @@
 package Net::Google::Analytics::DataFeedRequest;
-BEGIN {
-  $Net::Google::Analytics::DataFeedRequest::VERSION = '0.11000';
-}
 use strict;
 
+# ABSTRACT: Google Analytics API data feed request
+
 use base qw(Net::Google::Analytics::FeedRequest);
 
 my @param_map = (
@@ -45,12 +44,17 @@ sub _params {
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
-Net::Google::Analytics::DataFeedRequest - Google Analytics API data feed
-request
+Net::Google::Analytics::DataFeedRequest - Google Analytics API data feed request
+
+=head1 VERSION
+
+version 0.11001
 
 =head1 DESCRIPTION
 
@@ -61,7 +65,7 @@ See
 L<http://code.google.com/apis/analytics/docs/gdata/gdataReferenceDataFeed.html#dataRequest>
 for a reference.
 
-=head1 ACCESSORS
+=head1 ATTRIBUTES
 
 =head2 ids
 
@@ -91,11 +95,14 @@ Nick Wellnhofer <wellnhofer@aevum.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) Nick Wellnhofer, 2010
+This software is copyright (c) 2010 by Nick Wellnhofer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.0 or,
-at your option, any later version of Perl 5 you may have available.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
+
